extract_file_payload

Function extract_file_payload 

pub fn extract_file_payload(first_line: &str, layer: &Layer) -> String
Extract the payload portion of file-format lines by stripping the header from the first line. For a file line like “13:20:58.310 [RRC] DL 0001 01 4601 DCCH-NR: RRC release”, this returns the part after the header prefix that is layer-specific payload.